# Plotting graphs
import tkinter as tk
from tkinter import messagebox, filedialog
import matplotlib.pyplot as plt
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg


class CSVPlotterApp:
    def __init__(self, root):
        # Initialize the application
        self.root = root
        self.root.title("ETC Data Plotter")
        self.root.geometry("600x400")

        # Create UI elements
        self.data_values_label = tk.Label(root, text="Data Values (comma-separated):")
        self.data_values_label.pack(pady=10)

        self.data_values_entry = tk.Entry(root, width=50)
        self.data_values_entry.pack(pady=5)

        self.plot_button = tk.Button(root, text="Plot Graph", command=self.plot_graph)
        self.plot_button.pack(pady=10)

        self.save_button = tk.Button(root, text="Save Graph", command=self.save_graph)
        self.save_button.pack(pady=5)

        self.reset_button = tk.Button(root, text='Reset', command=self.reset)
        self.reset_button.pack(pady=15)

        # Create a Matplotlib figure and canvas for embedding the plot in Tkinter
        self.figure, self.ax = plt.subplots(figsize=(5, 4), tight_layout=True)
        self.canvas = FigureCanvasTkAgg(self.figure, master=root)
        self.canvas_widget = self.canvas.get_tk_widget()
        self.canvas_widget.pack(pady=10)

    def plot_graph(self):
        # Function to plot a graph based on user-input data values
        data_values_str = self.data_values_entry.get()

        if not data_values_str:
            messagebox.showerror("Error", "Please enter data values.")
            return

        try:
            # Convert the input string to a list of numerical values
            data_values_list = [float(value) for value in data_values_str.split(",")]
            L = len(data_values_list) + 1
            categories = list(range(1, L))

            # Veryfing the data is correct
            print('data_values_list=', data_values_list)
            print('categories=', categories)

            # Clear existing plot and create a new bar chart
            self.ax.clear()
            self.ax.bar(categories, data_values_list, color='blue')
            self.ax.set_xlabel("Categories")
            self.ax.set_ylabel("Values")
            self.ax.set_title("Bar Graph")

            # Update the Tkinter canvas to display the new plot
            self.canvas.draw()

        except ValueError:
            messagebox.showerror("Error", "Invalid data values. Please enter numerical values separated by commas.")

    def save_graph(self):
        # Function to save the current graph to a user-specified file path
        file_path = filedialog.asksaveasfilename(defaultextension=".png",
                                                 filetypes=[("PNG files", "*.png"), ("All files", "*.*")])

        if file_path:
            # Save the current figure to the specified file path in PNG format
            self.figure.savefig(file_path)
            messagebox.showinfo("Save Successful", "Graph saved successfully!")

    def reset(self):
        # Clear the entry field
        self.data_values_entry.delete(0, 'end')

        # Clear any existing plot on the graph
        self.ax.clear()
        self.canvas.draw()

        # Print a message to indicate that the form has been reset
        print("Form reset successfully.")


if __name__ == "__main__":
    # Create the main Tkinter window and start the application
    root = tk.Tk()
    app = CSVPlotterApp(root)
    root.mainloop()
